"use strict";

this.name 	 = "Spectroscope";
this.author 	 = "Wildeblood & rustem (edit)";
this.copyright	 = "March 2016";
this.licence 	 = "CC-BY-SA 4.0";
this.version 	 = "0.0.2"; 
this.description = "Converts values set in planetinfo.plist into descriptive text strings";

/* ====================================================================================
			SPECTROSCOPE

	Converts values set in planetinfo.plist and found in system.info.sun_color 
	into descriptive text strings. These are not computed values, so...
	Setting sun_color = "1.0 0.0 0.0" in planetinfo.plist returns null, even though 
	it creates the same colour star in the game as setting sun_color = "redColor".
======================================================================================= */

this.$spectroscope = function(colour)
	{
	if (!colour) colour = system.info.sun_color;
	if (!colour) return false;
	switch (colour)
			{										//The HZ range for stars calculated from formula: sqrt[L]
			case "M0": //colour = "class M0 star"; break;	//magentaColor ~ 0.6*Sun	// HZ ~ 0.30 AU // 0.19 - 0.40
			case "K8": colour = "class K8 star"; break;	//redColor			// HZ ~ 0.35 AU // 0.24 - 0.50
			case "K2": colour = "class K2 star"; break;	//orangeColor			// HZ ~ 0.55 AU // 0.37 - 0.77
			case "G2": colour = "class G2 star"; break;  	//yellowColor ~ 1.0*Sun 	// HZ ~ 1.10 AU // 0.72 - 1.52
			case "F2": colour = "class F2 star"; break;	//whiteColor			// HZ ~ 2.70 AU // 1.73 - 3.64
			case "A7": colour = "class A7 star"; break;	//cyanColor			// HZ ~ 3.50 AU // 2.29 - 4.81
			case "A2": colour = "class A2 star"; break;	//blueColor ~ 1.9*Sun		// HZ ~ 4.90 AU // 3.40 - 7.10
			default:   colour = "";
			}
	return colour;
	}

/* ====================================================================================
			EXAMPLE USE - ADD LINE TO SYSTEM DATA SCREEN
======================================================================================= */

this.guiScreenChanged = function()
	{
	if (guiScreen === "GUI_SCREEN_SYSTEM_DATA")
		{
		var info = System.infoForSystem(galaxyNumber, player.ship.targetSystem);
		if (info.sun_gone_nova) return;
		
		var name    = info.name;
		var sunName = info.sun_name;
		var colour  = info.sun_color;
		if (colour) var colourText = this.$spectroscope(colour);

		if (colourText && sunName) mission.addMessageText("The planet " + name + " orbits the " + colourText + " " + sunName + ".");
		else if (colourText) mission.addMessageText("The planet " + name + " orbits a " + colourText + ".");
		else if (sunName) mission.addMessageText("The planet " + name + " orbits the " + sunName + ".");
		}
	}

/* ====================================================================================
			THE END
======================================================================================= */
